@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import ClientVersionType, CloudHsmObjectStateType, HsmStatusType
 
@@ -75,7 +75,7 @@ AddTagsToResourceRequestRequestTypeDef = TypedDict(
     "AddTagsToResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagList": List["TagTypeDef"],
+        "TagList": Sequence["TagTypeDef"],
     },
 )
 
@@ -297,7 +297,7 @@ GetConfigRequestRequestTypeDef = TypedDict(
     {
         "ClientArn": str,
         "ClientVersion": ClientVersionType,
-        "HapgList": List[str],
+        "HapgList": Sequence[str],
     },
 )
 
@@ -395,7 +395,7 @@ _OptionalModifyHapgRequestRequestTypeDef = TypedDict(
     "_OptionalModifyHapgRequestRequestTypeDef",
     {
         "Label": str,
-        "PartitionSerialList": List[str],
+        "PartitionSerialList": Sequence[str],
     },
     total=False,
 )
@@ -478,7 +478,7 @@ RemoveTagsFromResourceRequestRequestTypeDef = TypedDict(
     "RemoveTagsFromResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeyList": List[str],
+        "TagKeyList": Sequence[str],
     },
 )
 
